@@ -238,7 +238,7 @@ class WeConnectSession(VWWebSession):
             if 'updated' in params and params['updated'] == 'dataprivacy':
                 raise AuthentificationError('You have to login at myvolkswagen.de and accept the terms and conditions')
             raise APICompatibilityError('No user id provided')
-        self.__userId = params['userId']  # pylint: disable=unused-private-member
+        self.userId = params['userId']
 
         # Now follow the forwarding until forwarding URL starts with 'weconnect://authenticated#'
         afterLoginUrl: str = login3Response.headers['Location']
