@@ -1,9 +1,17 @@
 from enum import Enum
+import re
 import logging
 
+import json
+import requests
+
+from weconnect.elements.error import Error
+from weconnect.errors import SetterError
+from weconnect.domain import Domain
+
 from weconnect.addressable import AddressableLeaf, ChangeableAttribute, AddressableAttribute, AliasChangeableAttribute
 from weconnect.elements.generic_settings import GenericSettings
-from weconnect.util import toBool, celsiusToKelvin, farenheitToKelvin
+from weconnect.util import celsiusToKelvin, farenheitToKelvin
 
 LOG = logging.getLogger("weconnect")
 
@@ -71,78 +79,17 @@ class ClimatizationSettings(GenericSettings):
         LOG.debug('Update Climatization settings from dict')
 
         if 'value' in fromDict:
-            if 'targetTemperature_K' in fromDict['value'] and fromDict['value']['targetTemperature_K'] is not None:
-                self.targetTemperature_K.setValueWithCarTime(
-                    float(fromDict['value']['targetTemperature_K']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.targetTemperature_K.enabled = False
-
-            if 'targetTemperature_C' in fromDict['value'] and fromDict['value']['targetTemperature_C'] is not None:
-                self.targetTemperature_C.setValueWithCarTime(
-                    float(fromDict['value']['targetTemperature_C']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.targetTemperature_C.enabled = False
-
-            if 'targetTemperature_F' in fromDict['value'] and fromDict['value']['targetTemperature_F'] is not None:
-                self.targetTemperature_F.setValueWithCarTime(
-                    float(fromDict['value']['targetTemperature_F']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.targetTemperature_F.enabled = False
-
-            if 'unitInCar' in fromDict['value'] and fromDict['value']['unitInCar']:
-                try:
-                    self.unitInCar.setValueWithCarTime(
-                        ClimatizationSettings.UnitInCar(fromDict['value']['unitInCar']), lastUpdateFromCar=None,
-                        fromServer=True)
-                except ValueError:
-                    self.unitInCar.setValueWithCarTime(ClimatizationSettings.UnitInCar.UNKNOWN,
-                                                       lastUpdateFromCar=None, fromServer=True)
-                    LOG.warning('An unsupported unitInCar: %s was provided,'
-                                ' please report this as a bug', fromDict['value']['unitInCar'])
-            else:
-                self.unitInCar.enabled = False
-
-            if 'climatisationWithoutExternalPower' in fromDict['value']:
-                self.climatisationWithoutExternalPower.setValueWithCarTime(
-                    toBool(fromDict['value']['climatisationWithoutExternalPower']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.climatisationWithoutExternalPower.enabled = False
-
-            if 'climatizationAtUnlock' in fromDict['value']:
-                self.climatizationAtUnlock.setValueWithCarTime(
-                    toBool(fromDict['value']['climatizationAtUnlock']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.climatizationAtUnlock.enabled = False
-
-            if 'windowHeatingEnabled' in fromDict['value']:
-                self.windowHeatingEnabled.setValueWithCarTime(
-                    toBool(fromDict['value']['windowHeatingEnabled']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.windowHeatingEnabled.enabled = False
-
-            if 'zoneFrontLeftEnabled' in fromDict['value']:
-                self.zoneFrontLeftEnabled.setValueWithCarTime(
-                    toBool(fromDict['value']['zoneFrontLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.zoneFrontLeftEnabled.enabled = False
-
-            if 'zoneFrontRightEnabled' in fromDict['value']:
-                self.zoneFrontRightEnabled.setValueWithCarTime(
-                    toBool(fromDict['value']['zoneFrontRightEnabled']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.zoneFrontRightEnabled.enabled = False
-
-            if 'zoneRearLeftEnabled' in fromDict['value']:
-                self.zoneRearLeftEnabled.setValueWithCarTime(
-                    toBool(fromDict['value']['zoneRearLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.zoneRearLeftEnabled.enabled = False
-
-            if 'zoneRearRightEnabled' in fromDict['value']:
-                self.zoneRearRightEnabled.setValueWithCarTime(
-                    toBool(fromDict['value']['zoneRearRightEnabled']), lastUpdateFromCar=None, fromServer=True)
-            else:
-                self.zoneRearRightEnabled.enabled = False
+            self.targetTemperature_K.fromDict(fromDict['value'], 'targetTemperature_K')
+            self.targetTemperature_C.fromDict(fromDict['value'], 'targetTemperature_C')
+            self.targetTemperature_F.fromDict(fromDict['value'], 'targetTemperature_F')
+            self.unitInCar.fromDict(fromDict['value'], 'unitInCar')
+            self.climatisationWithoutExternalPower.fromDict(fromDict['value'], 'climatisationWithoutExternalPower')
+            self.climatizationAtUnlock.fromDict(fromDict['value'], 'climatizationAtUnlock')
+            self.windowHeatingEnabled.fromDict(fromDict['value'], 'windowHeatingEnabled')
+            self.zoneFrontLeftEnabled.fromDict(fromDict['value'], 'zoneFrontLeftEnabled')
+            self.zoneFrontRightEnabled.fromDict(fromDict['value'], 'zoneFrontRightEnabled')
+            self.zoneRearLeftEnabled.fromDict(fromDict['value'], 'zoneRearLeftEnabled')
+            self.zoneRearRightEnabled.fromDict(fromDict['value'], 'zoneRearRightEnabled')
         else:
             self.targetTemperature_K.enabled = False
             self.targetTemperature_C.enabled = False
@@ -195,6 +142,57 @@ class ClimatizationSettings(GenericSettings):
             string += f'\n\tHeating Rear Right Seat: {self.zoneRearRightEnabled.value}'
         return string
 
+    def valueChanged(self, element, flags):  # noqa: C901
+        if flags & AddressableLeaf.ObserverEvent.VALUE_CHANGED \
+                and not flags & AddressableLeaf.ObserverEvent.UPDATED_FROM_SERVER:
+            url = f'https://mobileapi.apps.emea.vwapps.io/vehicles/{self.vehicle.vin.value}/climatisation/settings'
+            settingsDict = dict()
+            regex = re.compile('zone(Front|Rear)(Right|Left)Enabled')
+            if self.targetTemperature_C.enabled:
+                settingsDict['targetTemperature'] = self.targetTemperature_C.value
+                settingsDict['targetTemperatureUnit'] = ClimatizationSettings.UnitInCar.CELSIUS.value
+            elif self.targetTemperature_F.enabled:
+                settingsDict['targetTemperature'] = self.targetTemperature_F.value
+                settingsDict['targetTemperatureUnit'] = ClimatizationSettings.UnitInCar.FARENHEIT.value
+            else:
+                settingsDict['targetTemperature'] = 20.0
+                settingsDict['targetTemperatureUnit'] = ClimatizationSettings.UnitInCar.CELSIUS.value
+
+            if self.climatisationWithoutExternalPower.enabled:
+                settingsDict['climatisationWithoutExternalPower'] = self.climatisationWithoutExternalPower.value
+            if self.climatizationAtUnlock.enabled:
+                settingsDict['climatizationAtUnlock'] = self.climatizationAtUnlock.value
+            if self.windowHeatingEnabled.enabled:
+                settingsDict['windowHeatingEnabled'] = self.windowHeatingEnabled.value
+            for child in self.getLeafChildren():
+                if re.match(regex, child.getLocalAddress()):
+                    settingsDict[child.getLocalAddress()] = child.value
+            data = json.dumps(settingsDict)
+            putResponse = self.vehicle.weConnect.session.put(url, data=data, allow_redirects=True)
+            if putResponse.status_code != requests.codes['ok']:
+                errorDict = putResponse.json()
+                if errorDict is not None and 'error' in errorDict:
+                    error = Error(localAddress='error', parent=self, fromDict=errorDict['error'])
+                    if error is not None:
+                        message = ''
+                        if error.message.enabled and error.message.value is not None:
+                            message += error.message.value
+                        if error.info.enabled and error.info.value is not None:
+                            message += ' - ' + error.info.value
+                        if error.retry.enabled and error.retry.value is not None:
+                            if error.retry.value:
+                                message += ' - Please retry in a moment'
+                            else:
+                                message += ' - No retry possible'
+                        raise SetterError(f'Could not set value ({message})')
+                    else:
+                        raise SetterError(f'Could not set value ({putResponse.status_code})')
+                raise SetterError(f'Could not not set value ({putResponse.status_code})')
+            responseDict = putResponse.json()
+            if 'data' in responseDict and 'requestID' in responseDict['data']:
+                if self.vehicle.requestTracker is not None:
+                    self.vehicle.requestTracker.trackRequest(responseDict['data']['requestID'], Domain.ALL, 20, 120)
+
     class UnitInCar(Enum,):
         CELSIUS = 'celsius'
         FARENHEIT = 'farenheit'
