@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Dict, List, Set, Tuple, Callable, Any, Optional
+from typing import Dict, List, Set, Tuple, Callable, Any, Optional, Union
 
 import os
 import string
@@ -14,6 +14,7 @@ from weconnect.auth.session_manager import SessionManager, Service, SessionUser
 from weconnect.elements.vehicle import Vehicle
 from weconnect.domain import Domain
 from weconnect.elements.charging_station import ChargingStation
+from weconnect.elements.general_controls import GeneralControls
 from weconnect.addressable import AddressableLeaf, AddressableObject, AddressableDict
 from weconnect.errors import RetrievalError
 from weconnect.weconnect_errors import ErrorEventType
@@ -29,6 +30,7 @@ class WeConnect(AddressableObject):  # pylint: disable=too-many-instance-attribu
         self,
         username: str,
         password: str,
+        spin: Union[str, bool] = None,
         tokenfile: Optional[str] = None,
         updateAfterLogin: bool = True,
         loginOnInit: bool = False,
@@ -66,12 +68,13 @@ class WeConnect(AddressableObject):  # pylint: disable=too-many-instance-attribu
         super().__init__(localAddress='', parent=None)
         self.username: str = username
         self.password: str = password
+        self.spin: Union[str, bool] = spin
 
-        self.__userId: Optional[str] = None  # pylint: disable=unused-private-member
         self.__session: requests.Session = requests.Session()
 
         self.__vehicles: AddressableDict[str, Vehicle] = AddressableDict(localAddress='vehicles', parent=self)
         self.__stations: AddressableDict[str, ChargingStation] = AddressableDict(localAddress='chargingStations', parent=self)
+        self.__controls: GeneralControls = GeneralControls(localAddress='controls', parent=self)
         self.__cache: Dict[str, Any] = {}
         self.fixAPI: bool = fixAPI
         self.maxAge: Optional[int] = maxAge
@@ -226,8 +229,8 @@ class WeConnect(AddressableObject):  # pylint: disable=too-many-instance-attribu
             url += f'&locale={useLocale}'
         if searchRadius is not None:
             url += f'&searchRadius={searchRadius}'
-        if self.__userId is not None:
-            url += f'&userId={self.__userId}'
+        if self.session.userId is not None:
+            url += f'&userId={self.session.userId}'
         data = self.fetchData(url, force)
         if data is not None:
             if 'chargingStations' in data and data['chargingStations']:
@@ -251,8 +254,8 @@ class WeConnect(AddressableObject):  # pylint: disable=too-many-instance-attribu
                 url += f'&locale={self.useLocale}'
             if self.searchRadius is not None:
                 url += f'&searchRadius={self.searchRadius}'
-            if self.__userId is not None:
-                url += f'&userId={self.__userId}'
+            if self.session.userId is not None:
+                url += f'&userId={self.session.userId}'
             data = self.fetchData(url, force)
             if data is not None:
                 if 'chargingStations' in data and data['chargingStations']:
@@ -275,8 +278,11 @@ class WeConnect(AddressableObject):  # pylint: disable=too-many-instance-attribu
                     self.__cache[url] = (data, str(datetime.utcnow()))
 
     def getLeafChildren(self) -> List[AddressableLeaf]:
-        return [children for vehicle in self.__vehicles.values() for children in vehicle.getLeafChildren()] \
+        leafChildren = [children for vehicle in self.__vehicles.values() for children in vehicle.getLeafChildren()] \
             + [children for station in self.__stations.values() for children in station.getLeafChildren()]
+        if self.__controls.spinControl is not None and self.__controls.spinControl.enabled:
+            leafChildren += [self.__controls.spinControl]
+        return leafChildren
 
     def __str__(self) -> str:
         returnString: str = ''
